@@ -24,13 +24,19 @@ int unsetenv(char *key);
 void clearenv(void);
 #endif
 #ifndef HAVE_STRCASECMP
-int strcasecmp(char *str1, char *str2);
+int strcasecmp(const char *str1, const char *str2);
 #endif
 #ifndef HAVE_STRNCASECMP
-int strncasecmp(char *str1, char *str2, int len);
+int strncasecmp(const char *str1, const char *str2, int len);
+#endif
+#ifndef HAVE_STRNSTR
+const char *strnstr(const char *haystack, const char *needle, int len);
 #endif
 #ifndef HAVE_STRCASESTR
-char *strcasestr(char *haystack, char *needle);
+const char *strcasestr(const char *haystack, const char *needle);
+#endif
+#ifndef HAVE_STRNCASESTR
+const char *strncasestr(const char *haystack, const char *needle, int len);
 #endif
 
 #endif
