@@ -254,7 +254,9 @@ t_fcgi_server *fcgi_server_match(t_fcgi_server *fcgi_server, t_charlist *fastcgi
 		fcgi = fcgi_server;
 		while (fcgi != NULL) {
 			if (strcmp(fastcgi->item[i], fcgi->fcgi_id) == 0) {
-				if (in_charlist(extension, &(fcgi->extension))) {
+				if (fcgi->extension.size == 0) {
+					return fcgi;
+				} else if (in_charlist(extension, &(fcgi->extension))) {
 					return fcgi;
 				}
 			}
