@@ -16,7 +16,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdbool.h>
-#include <termios.h>
 #include <unistd.h>
 #include <string.h>
 #include <pthread.h>
@@ -88,25 +87,23 @@ void init_command_module(void) {
 int add_admin(int sock) {
 	t_admin *new;
 
-	if ((new = (t_admin*)malloc(sizeof(t_admin))) != NULL) {
-		if ((new->fp = fdopen(sock, "r+")) != NULL) {
-			fprintf(new->fp, "\n\033[02;31mWelcome to the Hiawatha CommandChannel\033[00m\n");
-			fprintf(new->fp, "Password: \0337\033[00;30;40m"); /* Save cursor position and change color to black */
-			fflush(new->fp);
-
-			new->next = adminlist;
-			new->socket = sock;
-			new->authenticated = false;
-			new->timer = MAX_IDLE_TIME;
-			adminlist = new;
-
-			return 0;
-		} else {
-			return -1;
-		}
-	} else {
+	if ((new = (t_admin*)malloc(sizeof(t_admin))) == NULL) {
+		return -1;
+	} else if ((new->fp = fdopen(sock, "r+")) == NULL) {
 		return -1;
 	}
+
+	fprintf(new->fp, "\n\033[02;31mWelcome to the Hiawatha CommandChannel\033[00m\n");
+	fprintf(new->fp, "Password: \0337\033[00;30;40m"); /* Save cursor position and change color to black */
+	fflush(new->fp);
+
+	new->next = adminlist;
+	new->socket = sock;
+	new->authenticated = false;
+	new->timer = MAX_IDLE_TIME;
+	adminlist = new;
+
+	return 0;
 }
 
 /* An administrator has left the CommandChannel
@@ -385,7 +382,8 @@ int handle_admin(t_admin *admin, t_config *config) {
 		} else if (admin->authenticated) {
 			retval = run_command(remove_spaces(line), admin->fp, config);
 		} else {
-			fprintf(admin->fp, "\0338\033[K\0338\n"); /* Restore cursor position and color and erase to end of line */
+			fprintf(admin->fp, "\0338\033[A\033[K\0338\n"); /* Restore cursor position and color and erase to end of line */
+
 			pwd = remove_spaces(line);
 			md5_hash(pwd, strlen(pwd), encrypted);
 			if ((admin->authenticated = (strcmp(encrypted, config->command_port->binding_id) == 0)) == false) {
