@@ -1400,7 +1400,7 @@ void connection_handler(t_session *session) {
 #endif
 			reset_session(session);
 
-			if (session->keep_alive && (session->config->ban_on_flooding > 0)) {
+			if ((session->kept_alive > 0) && (session->config->ban_on_flooding > 0)) {
 				if (client_is_flooding(session)) {
 					if (ip_allowed(&(session->ip_address), session->config->banlist_mask) != deny) {
 						ban_ip(&(session->ip_address), session->config->ban_on_flooding, session->config->kick_on_ban);
@@ -1880,7 +1880,7 @@ int run_server(t_settings *settings) {
 	binding = config->binding;
 	while (binding != NULL) {
 		if (binding->use_ssl) {
-			if ((binding->ssl_context = ssl_binding(binding->ssl_key_cert, binding->required_ca, binding->verify_depth, config->dh_file, config->allowed_ciphers)) == NULL) {
+			if ((binding->ssl_context = ssl_binding(binding->ssl_key_cert, binding->required_ca, binding->verify_depth, binding->port, config->dh_file, config->allowed_ciphers)) == NULL) {
 				perror("bind https");
 				return -1;
 			}
