@@ -150,7 +150,7 @@ static int load_dh_params(SSL_CTX *context, char *file) {
 	return 0;
 }
 
-SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, char *dh_file, char *ciphers) {
+SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, int port, char *dh_file, char *ciphers) {
 	SSL_METHOD *meth;
 	SSL_CTX    *context;
 	STACK_OF(X509_NAME) *ca_list;
@@ -184,8 +184,9 @@ SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, char *dh_fi
 	}
 
 	if (ca_cert != NULL) {
-		SSL_CTX_set_verify_depth(context, verify_depth);
 		SSL_CTX_set_verify(context, SSL_VERIFY_PEER | SSL_VERIFY_FAIL_IF_NO_PEER_CERT, 0);
+		SSL_CTX_set_verify_depth(context, verify_depth);
+
 		if (SSL_CTX_load_verify_locations(context, ca_cert, NULL) != 1) {
 			fprintf(stderr, "Error while setting CA verify locations\n");
 			return NULL;
@@ -195,6 +196,7 @@ SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, char *dh_fi
 			fprintf(stderr, "Error while loading CA certificate file\n");
 			return NULL;
 		}
+
 		SSL_CTX_set_client_CA_list(context, ca_list);
 	}
 
@@ -204,6 +206,7 @@ SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, char *dh_fi
 			return NULL;
 		}
 	}
+
 	if (ciphers != NULL) {
 		if (SSL_CTX_set_cipher_list(context, ciphers) == 0) {
 			fprintf(stderr, "Error while setting cipher list\n");
@@ -211,6 +214,8 @@ SSL_CTX *ssl_binding(char *keyfile, char *ca_cert, int verify_depth, char *dh_fi
 		}
 	}
 
+	SSL_CTX_set_session_id_context(context, (void*)&port, sizeof(port));
+
 	return context;
 }
 
