@@ -17,7 +17,7 @@
 #include <stdbool.h>
 #include <regex.h>
 
-int  str2int(const char *str);
+int  str2int(char *str);
 char *remove_spaces(char *str);
 char *uncomment(char *str);
 char *strlower(char *str);
