@@ -113,10 +113,11 @@ static int send_to_client(t_session *session, const char *buffer, int size) {
 				if ((errno == EAGAIN) || (errno == EWOULDBLOCK)) {
 					log_error(session, "send timeout");
 				} else if ((errno != EPIPE) && (errno != ECONNRESET)) {
-					log_error(session, "socket error");
+					log_error(session, "error while sending response");
 				}
 				close_socket(session);
 				session->keep_alive = false;
+				session->error_cause = ec_SOCKET_WRITE_ERROR;
 				return -1;
 			}
 		} else {
