@@ -258,6 +258,18 @@ bool toolkit_setting(char *key, char *value, t_url_toolkit *toolkit) {
 		if ((new_rule->parameter = strdup(value)) == NULL) {
 			return false;
 		}
+	} else if (strcmp(key, "oldbrowser") == 0) {
+		/* Old browser
+		 */
+		new_rule->condition = tc_oldbrowser;
+		new_rule->operation = to_replace;
+		new_rule->flow = tf_exit;
+
+		if (valid_uri(value) == false) {
+			return false;
+		} else if ((new_rule->parameter = strdup(value)) == NULL) {
+			return false;
+		}
 	} else if (strcmp(key, "skip") == 0) {
 		/* Skip
 		 */
@@ -454,7 +466,8 @@ static int do_rewrite(char *url, regex_t *regexp, regmatch_t *pmatch, char *rep,
 	return 0;
 }
 
-void init_toolkit_options(t_toolkit_options *options, char *website_root, t_url_toolkit *toolkit, bool use_ssl) {
+void init_toolkit_options(t_toolkit_options *options, char *website_root, t_url_toolkit *toolkit,
+	                      bool use_ssl, t_headerfield *headerfields) {
 	options->sub_depth = 0;
 	options->new_url = NULL;
 	options->website_root = website_root;
@@ -463,6 +476,7 @@ void init_toolkit_options(t_toolkit_options *options, char *website_root, t_url_
 	options->expire = -1;
 	options->url_toolkit = toolkit;
 	options->use_ssl = use_ssl;
+	options->headerfields = headerfields;
 }
 
 int use_toolkit(char *url, char *toolkit_id, t_toolkit_options *options) {
@@ -473,6 +487,7 @@ int use_toolkit(char *url, char *toolkit_id, t_toolkit_options *options) {
 	t_fsbool is_dir;
 	char *file, *qmark;
 	regmatch_t pmatch[REGEXEC_NMATCH];
+	char *user_agent;
 
 	if (options == NULL) {
 		return UT_ERROR;
@@ -556,6 +571,17 @@ int use_toolkit(char *url, char *toolkit_id, t_toolkit_options *options) {
 				condition_oke = options->use_ssl;
 				break;
 #endif
+			case tc_oldbrowser:
+				/* Old browser
+				 */
+				if ((user_agent = get_headerfield("User-Agent:", options->headerfields)) != NULL) {
+					if (strstr(user_agent, "MSIE 6") != NULL) {
+						condition_oke = true;
+					} else if (strstr(user_agent, "MSIE 5") != NULL) {
+						condition_oke = true;
+					}
+				}
+				break;
 		}
 
 		/* Condition not oke
@@ -665,6 +691,16 @@ int use_toolkit(char *url, char *toolkit_id, t_toolkit_options *options) {
 				 */
 				options->ban = rule->value;
 				break;
+			case to_replace:
+				/* Replace URL
+				 */
+				if (replaced) {
+					free(url);
+				}
+				if ((options->new_url = strdup(rule->parameter)) == NULL) {
+					return UT_ERROR;
+				}
+				break;
 		}
 
 		/* Flow
